Index: chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h |
diff --git a/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h b/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h |
index f51bb83750cce763d3917b80e69671882478cdb0..39d998f895c5ff107ca9f20a653b97784db81fdc 100644 |
--- a/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h |
+++ b/chrome/browser/ui/ash/app_list/test/app_list_service_ash_test_api.h |
@@ -8,19 +8,19 @@ |
#include "base/macros.h" |
namespace app_list { |
-class AppListShowerImpl; |
+class AppListPresenterImpl; |
class AppListView; |
class AppsGridView; |
class StartPageView; |
} |
// Accesses private data from an AppListServiceAsh and AppListShowerImpl |
// for testing. |
class AppListServiceAshTestApi { |
public: |
AppListServiceAshTestApi(); |
- app_list::AppListShowerImpl* GetAppListShower() const; |
+ app_list::AppListPresenterImpl* GetAppListPresenter() const; |
app_list::AppListView* GetAppListView() const; |
@@ -8,19 +8,19 @@ |
class StartPageView; |
} |
-// Accesses private data from an AppListServiceAsh and AppListShowerImpl |
+// Accesses private data from an AppListServiceAsh and AppListPresenterImpl |
// for testing. |
class AppListServiceAshTestApi { |